[U-Boot] [PATCH 1/6] dm: Rename dev_get_parentdata() to dev_get_parent_priv()

Simon Glass sjg at chromium.org
Tue Sep 29 07:32:01 CEST 2015


The current name is inconsistent with other driver model data access
functions. Rename it and fix up all users.

Signed-off-by: Simon Glass <sjg at chromium.org>
---

 common/cmd_usb.c                  | 10 +++++-----
 common/usb_hub.c                  |  4 ++--
 common/usb_storage.c              |  2 +-
 doc/driver-model/usb-info.txt     |  4 ++--
 drivers/core/device.c             |  2 +-
 drivers/misc/cros_ec_spi.c        |  4 ++--
 drivers/mtd/spi/sf_dataflash.c    |  2 +-
 drivers/mtd/spi/sf_probe.c        |  2 +-
 drivers/spi/fsl_qspi.c            |  2 +-
 drivers/spi/ich.c                 |  2 +-
 drivers/spi/soft_spi.c            |  2 +-
 drivers/spi/spi-uclass.c          |  8 ++++----
 drivers/usb/eth/smsc95xx.c        |  4 ++--
 drivers/usb/eth/usb_ether.c       |  2 +-
 drivers/usb/host/ehci-hcd.c       |  6 +++---
 drivers/usb/host/usb-uclass.c     |  8 ++++----
 drivers/usb/host/xhci.c           |  4 ++--
 drivers/usb/musb-new/usb-compat.h | 10 +++++-----
 include/dm/device.h               | 10 +++++-----
 include/pci.h                     |  2 +-
 include/spi.h                     |  2 +-
 include/usb.h                     |  2 +-
 test/dm/bus.c                     | 26 +++++++++++++-------------
 23 files changed, 60 insertions(+), 60 deletions(-)

diff --git a/common/cmd_usb.c b/common/cmd_usb.c
index 6bdbbc5..1ef55dc 100644
--- a/common/cmd_usb.c
+++ b/common/cmd_usb.c
@@ -281,7 +281,7 @@ static struct usb_device *usb_find_device(int devnum)
 
 		if (!device_active(hub))
 			continue;
-		udev = dev_get_parentdata(hub);
+		udev = dev_get_parent_priv(hub);
 		if (udev->devnum == devnum)
 			return udev;
 
@@ -291,7 +291,7 @@ static struct usb_device *usb_find_device(int devnum)
 			if (!device_active(hub))
 				continue;
 
-			udev = dev_get_parentdata(dev);
+			udev = dev_get_parent_priv(dev);
 			if (udev->devnum == devnum)
 				return udev;
 		}
@@ -407,7 +407,7 @@ static void usb_show_tree_graph(struct usb_device *dev, char *pre)
 		if (!device_active(child))
 			continue;
 
-		udev = dev_get_parentdata(child);
+		udev = dev_get_parent_priv(child);
 
 		/* Ignore emulators, we only want real devices */
 		if (device_get_uclass_id(child) != UCLASS_USB_EMUL) {
@@ -553,7 +553,7 @@ static void show_info(struct udevice *dev)
 	struct udevice *child;
 	struct usb_device *udev;
 
-	udev = dev_get_parentdata(dev);
+	udev = dev_get_parent_priv(dev);
 	usb_display_desc(udev);
 	usb_display_config(udev);
 	for (device_find_first_child(dev, &child);
@@ -641,7 +641,7 @@ static int do_usb(cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
 
 			device_find_first_child(bus, &dev);
 			if (dev && device_active(dev)) {
-				udev = dev_get_parentdata(dev);
+				udev = dev_get_parent_priv(dev);
 				usb_show_tree(udev);
 			}
 		}
diff --git a/common/usb_hub.c b/common/usb_hub.c
index 415b45c..a92c9fb 100644
--- a/common/usb_hub.c
+++ b/common/usb_hub.c
@@ -230,7 +230,7 @@ int legacy_hub_port_reset(struct usb_device *dev, int port,
 #ifdef CONFIG_DM_USB
 int hub_port_reset(struct udevice *dev, int port, unsigned short *portstat)
 {
-	struct usb_device *udev = dev_get_parentdata(dev);
+	struct usb_device *udev = dev_get_parent_priv(dev);
 
 	return legacy_hub_port_reset(udev, port, portstat);
 }
@@ -610,7 +610,7 @@ int usb_hub_probe(struct usb_device *dev, int ifnum)
 #ifdef CONFIG_DM_USB
 int usb_hub_scan(struct udevice *hub)
 {
-	struct usb_device *udev = dev_get_parentdata(hub);
+	struct usb_device *udev = dev_get_parent_priv(hub);
 
 	return usb_hub_configure(udev);
 }
diff --git a/common/usb_storage.c b/common/usb_storage.c
index b390310..0ccaeb4 100644
--- a/common/usb_storage.c
+++ b/common/usb_storage.c
@@ -1408,7 +1408,7 @@ int usb_stor_get_info(struct usb_device *dev, struct us_data *ss,
 
 static int usb_mass_storage_probe(struct udevice *dev)
 {
-	struct usb_device *udev = dev_get_parentdata(dev);
+	struct usb_device *udev = dev_get_parent_priv(dev);
 	int ret;
 
 	usb_disable_asynch(1); /* asynch transfer not allowed */
diff --git a/doc/driver-model/usb-info.txt b/doc/driver-model/usb-info.txt
index 66f2dae..e07e5ba 100644
--- a/doc/driver-model/usb-info.txt
+++ b/doc/driver-model/usb-info.txt
@@ -84,7 +84,7 @@ The following primary data structures are in use:
 	This holds information about a device on the bus. All devices have
 	this structure, even the root hub. The controller itself does not
 	have this structure. You can access it for a device 'dev' with
-	dev_get_parentdata(dev). It matches the old structure except that the
+	dev_get_parent_priv(dev). It matches the old structure except that the
 	parent and child information is not present (since driver model
 	handles that). Once the device is set up, you can find the device
 	descriptor and current configuration descriptor in this structure.
@@ -279,7 +279,7 @@ USB hubs are scanned as in the section above. While hubs have their own
 uclass, they share some common elements with controllers:
 
 - they both attach private data to their children (struct usb_device,
-accessible for a child with dev_get_parentdata(child))
+accessible for a child with dev_get_parent_priv(child))
 - they both use usb_child_pre_probe() to set up their children as proper USB
 devices
 
diff --git a/drivers/core/device.c b/drivers/core/device.c
index 0bc04d4..6edf846 100644
--- a/drivers/core/device.c
+++ b/drivers/core/device.c
@@ -390,7 +390,7 @@ void *dev_get_uclass_priv(struct udevice *dev)
 	return dev->uclass_priv;
 }
 
-void *dev_get_parentdata(struct udevice *dev)
+void *dev_get_parent_priv(struct udevice *dev)
 {
 	if (!dev) {
 		dm_warn("%s: null device\n", __func__);
diff --git a/drivers/misc/cros_ec_spi.c b/drivers/misc/cros_ec_spi.c
index 0686925..253d91a 100644
--- a/drivers/misc/cros_ec_spi.c
+++ b/drivers/misc/cros_ec_spi.c
@@ -24,7 +24,7 @@ DECLARE_GLOBAL_DATA_PTR;
 int cros_ec_spi_packet(struct udevice *udev, int out_bytes, int in_bytes)
 {
 	struct cros_ec_dev *dev = dev_get_uclass_priv(udev);
-	struct spi_slave *slave = dev_get_parentdata(dev->dev);
+	struct spi_slave *slave = dev_get_parent_priv(dev->dev);
 	ulong start;
 	uint8_t byte;
 	int rv;
@@ -84,7 +84,7 @@ int cros_ec_spi_command(struct udevice *udev, uint8_t cmd, int cmd_version,
 		     uint8_t **dinp, int din_len)
 {
 	struct cros_ec_dev *dev = dev_get_uclass_priv(udev);
-	struct spi_slave *slave = dev_get_parentdata(dev->dev);
+	struct spi_slave *slave = dev_get_parent_priv(dev->dev);
 	int in_bytes = din_len + 4;	/* status, length, checksum, trailer */
 	uint8_t *out;
 	uint8_t *p;
diff --git a/drivers/mtd/spi/sf_dataflash.c b/drivers/mtd/spi/sf_dataflash.c
index 3111f4f..b2a56da 100644
--- a/drivers/mtd/spi/sf_dataflash.c
+++ b/drivers/mtd/spi/sf_dataflash.c
@@ -577,7 +577,7 @@ static struct flash_info *jedec_probe(struct spi_slave *spi, u8 *id)
  */
 static int spi_dataflash_probe(struct udevice *dev)
 {
-	struct spi_slave *spi = dev_get_parentdata(dev);
+	struct spi_slave *spi = dev_get_parent_priv(dev);
 	struct spi_flash *spi_flash;
 	struct flash_info *info;
 	u8 idcode[5];
diff --git a/drivers/mtd/spi/sf_probe.c b/drivers/mtd/spi/sf_probe.c
index 954376d..3bf03f7 100644
--- a/drivers/mtd/spi/sf_probe.c
+++ b/drivers/mtd/spi/sf_probe.c
@@ -471,7 +471,7 @@ int spi_flash_std_erase(struct udevice *dev, u32 offset, size_t len)
 
 int spi_flash_std_probe(struct udevice *dev)
 {
-	struct spi_slave *slave = dev_get_parentdata(dev);
+	struct spi_slave *slave = dev_get_parent_priv(dev);
 	struct dm_spi_slave_platdata *plat = dev_get_parent_platdata(dev);
 	struct spi_flash *flash;
 
diff --git a/drivers/spi/fsl_qspi.c b/drivers/spi/fsl_qspi.c
index 868df5f..02b557f 100644
--- a/drivers/spi/fsl_qspi.c
+++ b/drivers/spi/fsl_qspi.c
@@ -913,7 +913,7 @@ void spi_init(void)
 #else
 static int fsl_qspi_child_pre_probe(struct udevice *dev)
 {
-	struct spi_slave *slave = dev_get_parentdata(dev);
+	struct spi_slave *slave = dev_get_parent_priv(dev);
 
 	slave->max_write_size = TX_BUFFER_SIZE;
 
diff --git a/drivers/spi/ich.c b/drivers/spi/ich.c
index 2e388e7..9a3e002 100644
--- a/drivers/spi/ich.c
+++ b/drivers/spi/ich.c
@@ -739,7 +739,7 @@ static int ich_spi_child_pre_probe(struct udevice *dev)
 	struct udevice *bus = dev_get_parent(dev);
 	struct ich_spi_platdata *plat = dev_get_platdata(bus);
 	struct ich_spi_priv *priv = dev_get_priv(bus);
-	struct spi_slave *slave = dev_get_parentdata(dev);
+	struct spi_slave *slave = dev_get_parent_priv(dev);
 
 	/*
 	 * Yes this controller can only write a small number of bytes at
diff --git a/drivers/spi/soft_spi.c b/drivers/spi/soft_spi.c
index 6ae45f5..aa4abcc 100644
--- a/drivers/spi/soft_spi.c
+++ b/drivers/spi/soft_spi.c
@@ -200,7 +200,7 @@ static int soft_spi_ofdata_to_platdata(struct udevice *dev)
 
 static int soft_spi_probe(struct udevice *dev)
 {
-	struct spi_slave *slave = dev_get_parentdata(dev);
+	struct spi_slave *slave = dev_get_parent_priv(dev);
 	struct soft_spi_platdata *plat = dev->platdata;
 	int cs_flags, clk_flags;
 
diff --git a/drivers/spi/spi-uclass.c b/drivers/spi/spi-uclass.c
index d666272..58388ef 100644
--- a/drivers/spi/spi-uclass.c
+++ b/drivers/spi/spi-uclass.c
@@ -124,7 +124,7 @@ static int spi_post_probe(struct udevice *bus)
 static int spi_child_pre_probe(struct udevice *dev)
 {
 	struct dm_spi_slave_platdata *plat = dev_get_parent_platdata(dev);
-	struct spi_slave *slave = dev_get_parentdata(dev);
+	struct spi_slave *slave = dev_get_parent_priv(dev);
 
 	/*
 	 * This is needed because we pass struct spi_slave around the place
@@ -282,7 +282,7 @@ int spi_get_bus_and_cs(int busnum, int cs, int speed, int mode,
 		ret = device_probe(dev);
 		if (ret)
 			goto err;
-		slave = dev_get_parentdata(dev);
+		slave = dev_get_parent_priv(dev);
 		slave->dev = dev;
 	}
 
@@ -291,7 +291,7 @@ int spi_get_bus_and_cs(int busnum, int cs, int speed, int mode,
 		goto err;
 
 	*busp = bus;
-	*devp = dev_get_parentdata(dev);
+	*devp = dev_get_parent_priv(dev);
 	debug("%s: bus=%p, slave=%p\n", __func__, bus, *devp);
 
 	return 0;
@@ -320,7 +320,7 @@ struct spi_slave *spi_setup_slave_fdt(const void *blob, int node,
 	ret = device_get_child_by_of_offset(bus, node, &dev);
 	if (ret)
 		return NULL;
-	return dev_get_parentdata(dev);
+	return dev_get_parent_priv(dev);
 }
 
 /* Compatibility function - to be removed */
diff --git a/drivers/usb/eth/smsc95xx.c b/drivers/usb/eth/smsc95xx.c
index dc8fa88..d4b5ff4 100644
--- a/drivers/usb/eth/smsc95xx.c
+++ b/drivers/usb/eth/smsc95xx.c
@@ -945,7 +945,7 @@ int smsc95xx_eth_get_info(struct usb_device *dev, struct ueth_data *ss,
 #ifdef CONFIG_DM_ETH
 static int smsc95xx_eth_start(struct udevice *dev)
 {
-	struct usb_device *udev = dev_get_parentdata(dev);
+	struct usb_device *udev = dev_get_parent_priv(dev);
 	struct smsc95xx_private *priv = dev_get_priv(dev);
 	struct eth_pdata *pdata = dev_get_platdata(dev);
 
@@ -1029,7 +1029,7 @@ static int smsc95xx_free_pkt(struct udevice *dev, uchar *packet, int packet_len)
 
 int smsc95xx_write_hwaddr(struct udevice *dev)
 {
-	struct usb_device *udev = dev_get_parentdata(dev);
+	struct usb_device *udev = dev_get_parent_priv(dev);
 	struct eth_pdata *pdata = dev_get_platdata(dev);
 	struct smsc95xx_private *priv = dev_get_priv(dev);
 
diff --git a/drivers/usb/eth/usb_ether.c b/drivers/usb/eth/usb_ether.c
index 3c3e082..62d20f0 100644
--- a/drivers/usb/eth/usb_ether.c
+++ b/drivers/usb/eth/usb_ether.c
@@ -19,7 +19,7 @@
 
 int usb_ether_register(struct udevice *dev, struct ueth_data *ueth, int rxsize)
 {
-	struct usb_device *udev = dev_get_parentdata(dev);
+	struct usb_device *udev = dev_get_parent_priv(dev);
 	struct usb_interface_descriptor *iface_desc;
 	bool ep_in_found = false, ep_out_found = false;
 	struct usb_interface *iface;
diff --git a/drivers/usb/host/ehci-hcd.c b/drivers/usb/host/ehci-hcd.c
index 135ef72..c85dbce 100644
--- a/drivers/usb/host/ehci-hcd.c
+++ b/drivers/usb/host/ehci-hcd.c
@@ -303,7 +303,7 @@ static void ehci_update_endpt2_dev_n_port(struct usb_device *udev,
 
 	ttdev = udev;
 	parent = udev->dev;
-	uparent = dev_get_parentdata(parent);
+	uparent = dev_get_parent_priv(parent);
 
 	while (uparent->speed != USB_SPEED_HIGH) {
 		struct udevice *dev = parent;
@@ -313,9 +313,9 @@ static void ehci_update_endpt2_dev_n_port(struct usb_device *udev,
 			return;
 		}
 
-		ttdev = dev_get_parentdata(dev);
+		ttdev = dev_get_parent_priv(dev);
 		parent = dev->parent;
-		uparent = dev_get_parentdata(parent);
+		uparent = dev_get_parent_priv(parent);
 	}
 	parent_devnum = uparent->devnum;
 #else
diff --git a/drivers/usb/host/usb-uclass.c b/drivers/usb/host/usb-uclass.c
index c66ebb6..7f6a9a6 100644
--- a/drivers/usb/host/usb-uclass.c
+++ b/drivers/usb/host/usb-uclass.c
@@ -289,7 +289,7 @@ static struct usb_device *find_child_devnum(struct udevice *parent, int devnum)
 
 	if (!device_active(parent))
 		return NULL;
-	udev = dev_get_parentdata(parent);
+	udev = dev_get_parent_priv(parent);
 	if (udev->devnum == devnum)
 		return udev;
 
@@ -575,7 +575,7 @@ int usb_scan_device(struct udevice *parent, int port,
 	udev->portnr = port;
 	debug("Calling usb_setup_device(), portnr=%d\n", udev->portnr);
 	parent_udev = device_get_uclass_id(parent) == UCLASS_USB_HUB ?
-		dev_get_parentdata(parent) : NULL;
+		dev_get_parent_priv(parent) : NULL;
 	ret = usb_setup_device(udev, priv->desc_before_addr, parent_udev);
 	debug("read_descriptor for '%s': ret=%d\n", parent->name, ret);
 	if (ret)
@@ -638,7 +638,7 @@ int usb_detect_change(void)
 			if (!device_active(dev))
 				continue;
 
-			udev = dev_get_parentdata(dev);
+			udev = dev_get_parent_priv(dev);
 			if (usb_get_port_status(udev, udev->portnr, &status)
 					< 0)
 				/* USB request failed */
@@ -694,7 +694,7 @@ struct udevice *usb_get_bus(struct udevice *dev)
 
 int usb_child_pre_probe(struct udevice *dev)
 {
-	struct usb_device *udev = dev_get_parentdata(dev);
+	struct usb_device *udev = dev_get_parent_priv(dev);
 	struct usb_dev_platdata *plat = dev_get_parent_platdata(dev);
 	int ret;
 
diff --git a/drivers/usb/host/xhci.c b/drivers/usb/host/xhci.c
index 307e1a6..ca598aa 100644
--- a/drivers/usb/host/xhci.c
+++ b/drivers/usb/host/xhci.c
@@ -1119,7 +1119,7 @@ static struct usb_device *get_usb_device(struct udevice *dev)
 	if (device_get_uclass_id(dev) == UCLASS_USB)
 		udev = dev_get_uclass_priv(dev);
 	else
-		udev = dev_get_parentdata(dev);
+		udev = dev_get_parent_priv(dev);
 
 	return udev;
 }
@@ -1150,7 +1150,7 @@ static int xhci_submit_control_msg(struct udevice *dev, struct usb_device *udev,
 		} else {
 			while (!is_root_hub(hub->parent))
 				hub = hub->parent;
-			uhop = dev_get_parentdata(hub);
+			uhop = dev_get_parent_priv(hub);
 			root_portnr = uhop->portnr;
 		}
 	}
diff --git a/drivers/usb/musb-new/usb-compat.h b/drivers/usb/musb-new/usb-compat.h
index 53fe4ff..1c41e2a 100644
--- a/drivers/usb/musb-new/usb-compat.h
+++ b/drivers/usb/musb-new/usb-compat.h
@@ -82,7 +82,7 @@ static inline u16 find_tt(struct usb_device *udev)
 	 */
 	ttdev = udev;
 	parent = udev->dev;
-	uparent = dev_get_parentdata(parent);
+	uparent = dev_get_parent_priv(parent);
 
 	while (uparent->speed != USB_SPEED_HIGH) {
 		struct udevice *dev = parent;
@@ -92,9 +92,9 @@ static inline u16 find_tt(struct usb_device *udev)
 			return 0;
 		}
 
-		ttdev = dev_get_parentdata(dev);
+		ttdev = dev_get_parent_priv(dev);
 		parent = dev->parent;
-		uparent = dev_get_parentdata(parent);
+		uparent = dev_get_parent_priv(parent);
 	}
 
 	return (uparent->devnum << 8) | (ttdev->portnr - 1);
@@ -119,12 +119,12 @@ static inline struct usb_device *usb_dev_get_parent(struct usb_device *udev)
 	 * If these 2 are not the same we are being called from
 	 * usb_scan_device() and udev itself is the parent.
 	 */
-	if (dev_get_parentdata(udev->dev) != udev)
+	if (dev_get_parent_priv(udev->dev) != udev)
 		return udev;
 
 	/* We are being called normally, use the parent pointer */
 	if (device_get_uclass_id(parent) == UCLASS_USB_HUB)
-		return dev_get_parentdata(parent);
+		return dev_get_parent_priv(parent);
 
 	return NULL;
 }
diff --git a/include/pci.h b/include/pci.h
index e24c970..ed135a5 100644
--- a/include/pci.h
+++ b/include/pci.h
@@ -797,7 +797,7 @@ struct udevice;
  *
  * Every device on a PCI bus has this per-child data.
  *
- * It can be accessed using dev_get_parentdata(dev) if dev->parent is a
+ * It can be accessed using dev_get_parent_priv(dev) if dev->parent is a
  * PCI bus (i.e. UCLASS_PCI)
  *
  * @devfn:	Encoded device and function index - see PCI_DEVFN()
diff --git a/include/spi.h b/include/spi.h
index 51fdfd6..b4d2723 100644
--- a/include/spi.h
+++ b/include/spi.h
@@ -88,7 +88,7 @@ struct dm_spi_slave_platdata {
  * struct spi_slave - Representation of a SPI slave
  *
  * For driver model this is the per-child data used by the SPI bus. It can
- * be accessed using dev_get_parentdata() on the slave device. The SPI uclass
+ * be accessed using dev_get_parent_priv() on the slave device. The SPI uclass
  * sets uip per_child_auto_alloc_size to sizeof(struct spi_slave), and the
  * driver should not override it. Two platform data fields (max_hz and mode)
  * are copied into this structure to provide an initial value. This allows
diff --git a/include/usb.h b/include/usb.h
index 88ebbe6..3d0facb 100644
--- a/include/usb.h
+++ b/include/usb.h
@@ -96,7 +96,7 @@ enum {
  * (the hubs) have this as parent data. Hubs are children of controllers or
  * other hubs and there is always a single root hub for each controller.
  * Therefore struct usb_device can always be accessed with
- * dev_get_parentdata(dev), where dev is a USB device.
+ * dev_get_parent_priv(dev), where dev is a USB device.
  *
  * Pointers exist for obtaining both the device (could be any uclass) and
  * controller (UCLASS_USB) from this structure. The controller does not have
diff --git a/test/dm/bus.c b/test/dm/bus.c
index a215905..3b5a23b 100644
--- a/test/dm/bus.c
+++ b/test/dm/bus.c
@@ -46,7 +46,7 @@ static int testbus_child_post_bind(struct udevice *dev)
 
 static int testbus_child_pre_probe(struct udevice *dev)
 {
-	struct dm_test_parent_data *parent_data = dev_get_parentdata(dev);
+	struct dm_test_parent_data *parent_data = dev_get_parent_priv(dev);
 
 	parent_data->flag += FLAG_CHILD_PROBED;
 
@@ -64,7 +64,7 @@ static int testbus_child_pre_probe_uclass(struct udevice *dev)
 
 static int testbus_child_post_remove(struct udevice *dev)
 {
-	struct dm_test_parent_data *parent_data = dev_get_parentdata(dev);
+	struct dm_test_parent_data *parent_data = dev_get_parent_priv(dev);
 	struct dm_test_state *dms = test_state;
 
 	parent_data->flag += FLAG_CHILD_REMOVED;
@@ -215,20 +215,20 @@ static int test_bus_parent_data(struct unit_test_state *uts)
 
 	/* Check that parent data is allocated */
 	ut_assertok(device_find_child_by_seq(bus, 0, true, &dev));
-	ut_asserteq_ptr(NULL, dev_get_parentdata(dev));
+	ut_asserteq_ptr(NULL, dev_get_parent_priv(dev));
 	ut_assertok(device_get_child_by_seq(bus, 0, &dev));
-	parent_data = dev_get_parentdata(dev);
+	parent_data = dev_get_parent_priv(dev);
 	ut_assert(NULL != parent_data);
 
 	/* Check that it starts at 0 and goes away when device is removed */
 	parent_data->sum += 5;
 	ut_asserteq(5, parent_data->sum);
 	device_remove(dev);
-	ut_asserteq_ptr(NULL, dev_get_parentdata(dev));
+	ut_asserteq_ptr(NULL, dev_get_parent_priv(dev));
 
 	/* Check that we can do this twice */
 	ut_assertok(device_get_child_by_seq(bus, 0, &dev));
-	parent_data = dev_get_parentdata(dev);
+	parent_data = dev_get_parent_priv(dev);
 	ut_assert(NULL != parent_data);
 	parent_data->sum += 5;
 	ut_asserteq(5, parent_data->sum);
@@ -239,11 +239,11 @@ static int test_bus_parent_data(struct unit_test_state *uts)
 	uclass_foreach_dev(dev, uc) {
 		/* Ignore these if they are not on this bus */
 		if (dev->parent != bus) {
-			ut_asserteq_ptr(NULL, dev_get_parentdata(dev));
+			ut_asserteq_ptr(NULL, dev_get_parent_priv(dev));
 			continue;
 		}
 		ut_assertok(device_probe(dev));
-		parent_data = dev_get_parentdata(dev);
+		parent_data = dev_get_parent_priv(dev);
 
 		parent_data->sum = value;
 		value += 5;
@@ -255,7 +255,7 @@ static int test_bus_parent_data(struct unit_test_state *uts)
 		/* Ignore these if they are not on this bus */
 		if (dev->parent != bus)
 			continue;
-		parent_data = dev_get_parentdata(dev);
+		parent_data = dev_get_parent_priv(dev);
 
 		ut_asserteq(value, parent_data->sum);
 		value += 5;
@@ -311,10 +311,10 @@ static int dm_test_bus_parent_ops(struct unit_test_state *uts)
 		/* Ignore these if they are not on this bus */
 		if (dev->parent != bus)
 			continue;
-		ut_asserteq_ptr(NULL, dev_get_parentdata(dev));
+		ut_asserteq_ptr(NULL, dev_get_parent_priv(dev));
 
 		ut_assertok(device_probe(dev));
-		parent_data = dev_get_parentdata(dev);
+		parent_data = dev_get_parent_priv(dev);
 		ut_asserteq(FLAG_CHILD_PROBED, parent_data->flag);
 	}
 
@@ -322,10 +322,10 @@ static int dm_test_bus_parent_ops(struct unit_test_state *uts)
 		/* Ignore these if they are not on this bus */
 		if (dev->parent != bus)
 			continue;
-		parent_data = dev_get_parentdata(dev);
+		parent_data = dev_get_parent_priv(dev);
 		ut_asserteq(FLAG_CHILD_PROBED, parent_data->flag);
 		ut_assertok(device_remove(dev));
-		ut_asserteq_ptr(NULL, dev_get_parentdata(dev));
+		ut_asserteq_ptr(NULL, dev_get_parent_priv(dev));
 		ut_asserteq_ptr(dms->removed, dev);
 	}
 	test_state = NULL;
diff --git a/include/dm/device.h b/include/dm/device.h
index 8519612..f152008 100644
--- a/include/dm/device.h
+++ b/include/dm/device.h
@@ -233,18 +233,18 @@ void *dev_get_parent_platdata(struct udevice *dev);
 void *dev_get_uclass_platdata(struct udevice *dev);
 
 /**
  * dev_get_parentdata() - Get the parent data for a device
  *
- * The parent data is data stored in the device but owned by the parent.
- * For example, a USB device may have parent data which contains information
- * about how to talk to the device over USB.
+ * The parent private data is data stored in the device but owned by the
+ * parent. For example, a USB device may have parent data which contains
+ * information about how to talk to the device over USB.
  *
  * This checks that dev is not NULL, but no other checks for now
  *
  * @dev		Device to check
  * @return parent data, or NULL if none
  */
-void *dev_get_parentdata(struct udevice *dev);
+void *dev_get_parent_priv(struct udevice *dev);
 
 /**
  * dev_get_priv() - Get the private data for a device
@@ -233,18 +233,18 @@ void *dev_get_parent_platdata(struct udevice *dev);
 
 /**
- * dev_get_parentdata() - Get the parent data for a device
+ * dev_get_parent_priv() - Get the parent private data for a device
  *
-- 
2.6.0.rc2.230.g3dd15c0



More information about the U-Boot mailing list